@@ -181,7 +181,7 @@ def get_map_info(player_info, game_map):
 
         try:
             map_info_path = Path(__file__).resolve().parent / 'gamedata' / 'map_info.py'
-            with open(map_info_path, 'w') as map_info:
+            with open(map_info_path, 'w', encoding='utf-8') as map_info:
                 map_info.write(f'maps = {maps}')
         except OSError:
             logging.warning('Could not write map details to file')
